@@ -13,8 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -41,8 +41,9 @@ class IndexView(tables.DataTableView):
             apps = solum.apps.list()
         except Exception:
             apps = []
-            exceptions.handle(self.request,
-                              _('Unable to retrieve apps.'))
+            exceptions.handle(
+                self.request,
+                _('Unable to retrieve apps.'))
         return apps
 
 
@@ -109,9 +110,10 @@ class DetailView(tabs.TabView):
             app = solum.apps.find(name_or_id=application_id)
         except Exception:
             INDEX_URL = 'horizon:solum:applications:index'
-            exceptions.handle(self.request,
-                              _('Unable to retrieve application details.'),
-                              redirect=reverse(INDEX_URL))
+            exceptions.handle(
+                self.request,
+                _('Unable to retrieve application details.'),
+                redirect=reverse(INDEX_URL))
         context["app"] = app
         table = app_tables.ApplicationsTable(self.request)
         context["actions"] = table.render_row_actions(app)
