@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
@@ -21,9 +21,10 @@ import horizon
 class SolumPlugin(horizon.Dashboard):
     name = _("Solum")
     slug = "solum"
-    panels = ('applications', 'assemblies')
+    panels = ('applications', 'assemblies', 'languagepacks')
     default_panel = 'applications'
     nav = True
     supports_tenants = True
 
+
 horizon.register(SolumPlugin)
